@@ -39,8 +39,6 @@
 
 #define MIN_AUTHKEYS_LINE 10 /* "ssh-rsa AB" - short but doesn't matter */
 #define MAX_AUTHKEYS_LINE 1000 /* max length of a line in authkeys */
-#define MIN_AUTHKEYS_FILE MIN_AUTHKEYS_LINE
-#define MAX_AUTHKEYS_FILE 10000 /* should allow at least 20 authkeys */
 
 static int checkpubkey(unsigned char* algo, unsigned int algolen,
 		unsigned char* keyblob, unsigned int keybloblen);
@@ -62,6 +60,8 @@ void pubkeyauth() {
 	buffer * signbuf = NULL;
 	unsigned int sigoffset;
 	sign_key * key = NULL;
+	char* fp = NULL;
+	int type = -1;
 
 	TRACE(("enter pubkeyauth"));
 
@@ -89,8 +89,8 @@ void pubkeyauth() {
 	
 	/* get the key */
 	key = new_sign_key();
-	if (buf_get_pub_key(ses.payload, key, DROPBEAR_SIGNKEY_ANY) 
-			== DROPBEAR_FAILURE) {
+	type = DROPBEAR_SIGNKEY_ANY;
+	if (buf_get_pub_key(ses.payload, key, &type) == DROPBEAR_FAILURE) {
 		send_msg_userauth_failure(0, 1);
 		goto out;
 	}
@@ -108,18 +108,20 @@ void pubkeyauth() {
 
 	buf_setpos(signbuf, 0);
 	/* ... and finally verify the signature */
+	fp = sign_key_fingerprint(key, type);
 	if (buf_verify(ses.payload, key, buf_getptr(signbuf, signbuf->len),
 				signbuf->len) == DROPBEAR_SUCCESS) {
 		dropbear_log(LOG_NOTICE,
-				"pubkey auth succeeded for '%s' from %s",
-				ses.authstate.printableuser, ses.addrstring);
+				"pubkey auth succeeded for '%s' with key %s",
+				ses.authstate.printableuser, fp);
 		send_msg_userauth_success();
 	} else {
 		dropbear_log(LOG_WARNING,
-				"pubkey auth failure for '%s' from %s",
-				ses.authstate.printableuser, ses.addrstring);
+				"pubkey auth bad signature for '%s' with key %s",
+				ses.authstate.printableuser, fp);
 		send_msg_userauth_failure(0, 1);
 	}
+	m_free(fp);
 
 out:
 	/* cleanup stuff */
@@ -175,13 +177,14 @@ static int checkpubkey(unsigned char* algo, unsigned int algolen,
 	/* check that we can use the algo */
 	if (have_algo(algo, algolen, sshhostkey) == DROPBEAR_FAILURE) {
 		dropbear_log(LOG_WARNING,
-				"pubkey auth attempt with unknown algo '%s' for '%s' from %s",
-				algo, ses.authstate.printableuser, ses.addrstring);
+				"pubkey auth attempt with unknown algo for '%s'",
+				ses.authstate.printableuser);
 		goto out;
 	}
 
 	/* check file permissions, also whether file exists */
 	if (checkpubkeyperms() == DROPBEAR_FAILURE) {
+		TRACE(("bad authorized_keys permissions, or file doesn't exist"));
 		goto out;
 	}
 
@@ -303,14 +306,13 @@ out:
 static int getauthline(buffer * line, FILE * authfile) {
 
 	int c = EOF;
-	unsigned int count = 0;
 
 	TRACE(("enter getauthline"));
 
 	buf_setpos(line, 0);
 	buf_setlen(line, 0);
 
-	for (count = 0; count < line->size; count++) {
+	while (line->pos < line->size) {
 		c = fgetc(authfile); /*getc() is weird with some uClibc systems*/
 		if (c == EOF || c == '\n' || c == '\r') {
 			goto out;
@@ -326,7 +328,7 @@ out:
 	buf_setpos(line, 0);
 
 	/* if we didn't read anything before EOF or error, exit */
-	if (c == EOF && count == 0) {
+	if (c == EOF && line->pos == 0) {
 		TRACE(("leave getauthline: failure"));
 		return DROPBEAR_FAILURE;
 	} else {
