@@ -64,23 +64,8 @@ static void _dropbear_exit(int exitcode, const char* format, va_list param);
 int usingsyslog = 0; /* set by runopts, but required externally to sessions */
 void startsyslog() {
 
-	int fd;
-
 	openlog(PROGNAME, LOG_PID, LOG_AUTHPRIV);
 
-#ifndef DEBUG_TRACE
-	/* redirect stdin/stdout/stderr to /dev/null */
-	fd = open("/dev/null", O_RDWR);
-	if (fd != -1) {
-		dup2(fd, STDIN_FILENO);
-		dup2(fd, STDOUT_FILENO);
-		dup2(fd, STDERR_FILENO);
-		if (fd > 2) {
-			close(fd);
-		}
-	}
-#endif
-	
 }
 #endif /* DISABLE_SYSLOG */
 
@@ -116,19 +101,17 @@ static void _dropbear_exit(int exitcode, const char* format, va_list param) {
 	} else if (ses.authstate.authdone) {
 		/* user has authenticated */
 		snprintf(fmtbuf, sizeof(fmtbuf),
-				"exit after auth (%s) from %s: %s", 
-				ses.authstate.printableuser, ses.addrstring, format);
-	} else if (ses.authstate.username) {
+				"exit after auth (%s): %s", 
+				ses.authstate.printableuser, format);
+	} else if (ses.authstate.printableuser) {
 		/* we have a potential user */
 		snprintf(fmtbuf, sizeof(fmtbuf), 
-				"exit before auth (user '%s', %d fails) from %s: %s",
-				ses.authstate.username, ses.authstate.failcount,
-				ses.addrstring, format);
+				"exit before auth (user '%s', %d fails): %s",
+				ses.authstate.printableuser, ses.authstate.failcount, format);
 	} else {
 		/* before userauth */
 		snprintf(fmtbuf, sizeof(fmtbuf), 
-				"exit before auth from %s: %s",
-				ses.addrstring, format);
+				"exit before auth: %s", format);
 	}
 
 	_dropbear_log(LOG_INFO, fmtbuf, param);
@@ -170,7 +153,7 @@ static void _dropbear_log(int priority, const char* format, va_list param) {
 					localtime(&timesec)) == 0) {
 			datestr[0] = '?'; datestr[1] = '\0';
 		}
-		fprintf(stderr, "%s %s\n", datestr, printbuf);
+		fprintf(stderr, "[%d] %s %s\n", getpid(), datestr, printbuf);
 	}
 }
 
@@ -188,16 +171,27 @@ void dropbear_trace(const char* format, ...) {
 #endif /* DEBUG_TRACE */
 
 /* Return a string representation of the socket address passed. The return
- * value is allocated with strdup() */
+ * value is allocated with malloc() */
 unsigned char * getaddrstring(struct sockaddr * addr) {
 
+	char *retstring;
+
+	/* space for "255.255.255.255:65535\0" = 22 */
+	retstring = m_malloc(22);
+
 	switch (addr->sa_family) {
 		case PF_INET: 
-			return strdup(inet_ntoa(((struct sockaddr_in *)addr)->sin_addr));
-	}
+			snprintf(retstring, 22, "%s:%hu",
+					inet_ntoa(((struct sockaddr_in *)addr)->sin_addr),
+					((struct sockaddr_in *)addr)->sin_port);
+			break;
 
-	/* Need to extend for IP6 */
-	return NULL;
+		default:
+			/* XXX ipv6 */
+			strcpy(retstring, "Bad protocol");
+
+	}
+	return retstring;
 
 }
 
@@ -223,75 +217,6 @@ char* getaddrhostname(struct sockaddr * addr) {
 
 	return strdup(retstring);
 }
-
-#ifndef HAVE_STRLCPY
-/* Implemented by matt as specified in freebsd 4.7 manpage.
- * We don't require great speed, is simply for use with sshpty code */
-size_t strlcpy(char *dst, const char *src, size_t size) {
-
-	size_t i;
-
-	/* this is undefined, though size==0 -> return 0 */
-	if (size < 1) {
-		return 0;
-	}
-
-	for (i = 0; i < size-1; i++) {
-		if (src[i] == '\0') {
-			break;
-		} else {
-			dst[i] = src[i];
-		}
-	}
-
-	dst[i] = '\0';
-	return strlen(src);
-
-}
-#endif /* HAVE_STRLCPY */
-
-#ifndef HAVE_STRNCAT
-/* taken from openbsd-compat for OpenSSH 3.6.1p1 */
-/* "$OpenBSD: strlcat.c,v 1.8 2001/05/13 15:40:15 deraadt Exp $"
- *
- * Appends src to string dst of size siz (unlike strncat, siz is the
- * full size of dst, not space left).  At most siz-1 characters
- * will be copied.  Always NUL terminates (unless siz <= strlen(dst)).
- * Returns strlen(src) + MIN(siz, strlen(initial dst)).
- * If retval >= siz, truncation occurred.
- */
-size_t
-strlcat(dst, src, siz)
-	char *dst;
-	const char *src;
-	size_t siz;
-{
-	register char *d = dst;
-	register const char *s = src;
-	register size_t n = siz;
-	size_t dlen;
-
-	/* Find the end of dst and adjust bytes left but don't go past end */
-	while (n-- != 0 && *d != '\0')
-		d++;
-	dlen = d - dst;
-	n = siz - dlen;
-
-	if (n == 0)
-		return(dlen + strlen(s));
-	while (*s != '\0') {
-		if (n != 1) {
-			*d++ = *s;
-			n--;
-		}
-		s++;
-	}
-	*d = '\0';
-
-	return(dlen + (s - src));	/* count does not include NUL */
-}
-#endif /* HAVE_STRLCAT */
-
 #ifdef DEBUG_TRACE
 void printhex(unsigned char* buf, int len) {
 
