@@ -40,6 +40,7 @@ extern int exitflag;
 void session_cleanup();
 void child_session(int sock, runopts *opts, int childpipe,
 		struct sockaddr *remoteaddr);
+void session_remoteclosed();
 
 struct key_context {
 
@@ -73,7 +74,6 @@ struct sshsession {
 	long connecttime; /* time of initial connection */
 
 	struct sockaddr *remoteaddr; /* the host and port of the client */
-	unsigned char *addrstring; /* the text version of remoteaddr */
 	unsigned char *hostname; /* the remote hostname */
 
 	int maxfd; /* the maximum file descriptor to check with select() */
@@ -87,6 +87,10 @@ struct sshsession {
 
 	unsigned char expecting; /* byte indicating what packet we expect next, 
 								or 0x00 for any */
+
+	unsigned char ignorenext; /* whether to ignore the next packet,
+								 used for kex_follows stuff */
+
 	
 	/* unencrypted write payload */
 	buffer *writepayload; /* this will actually refer to within clearwritebuf */
